@@ -20,6 +20,7 @@
 
 #include <libspi/remoteobject.h>
 
+#include <bonobo/bonobo-exception.h>
 #include "bonobo_socket_atk_object.h"
 #include "gail-gnome-debug.h"
 
@@ -44,11 +45,18 @@ bonobo_socket_atk_object_get_accessible (SpiRemoteObject *remote)
 
   g_return_val_if_fail (BONOBO_IS_SOCKET_ATK_OBJECT (remote), CORBA_OBJECT_NIL);
 
+  frame = bonobo_socket_atk_object_get_frame (BONOBO_SOCKET_ATK_OBJECT (remote));
+  g_return_val_if_fail (BONOBO_IS_CONTROL_FRAME (frame), CORBA_OBJECT_NIL);
+  control = bonobo_control_frame_get_control (frame);
+  g_return_val_if_fail (control != CORBA_OBJECT_NIL, CORBA_OBJECT_NIL);
+
   CORBA_exception_init (&env);
 
-  frame = bonobo_socket_atk_object_get_frame (BONOBO_SOCKET_ATK_OBJECT (remote));
-  control = bonobo_control_frame_get_control (frame);
   retval = Bonobo_Control_getAccessible (control, &env);
+  g_return_val_if_fail (retval != CORBA_OBJECT_NIL, CORBA_OBJECT_NIL);
+
+  if (BONOBO_EX (&env))
+	  retval = CORBA_OBJECT_NIL;
 
   CORBA_exception_free (&env);
 
